# Data je funkcija f(x) = a*sin(b*x + c) + d
# Prikazati uticaj parametara a,b,c,d na izgled
# grafika funkcije na intervalu [-8*pi, 8*pi] za
# sledece vrednosti parametara:
# 1. a,b,c,d = 1,1,0,0
# 2. a,b,c,d = 1,2,0,2.5
# 3. a,b,c,d = 2,1,0,-3 
# 4. a,b,c,d = 0.5,1,pi/2,4.5
# 5. a,b,c,d = 2,4,0,7.5
# 6. a,b,c,d = 3,1/2,pi/3,-8
#
# Nacrtati dva grafika. 
# Prvi grafik treba da bude matrica 2x3 manjih crteza koji 
# odgovoraju slucajevima 1-6.
# Drugi grafik treba da bude jedan crtez koji sadrzi sve slucajeva.
# Sve grafike uredno formatirati.

import numpy as np
import matplotlib.pyplot as plt

# definisemo funkciju
def f(fun, x, a,b,c,d):
    return a*fun(b*x+c) + d

# kreiramo podelu intervala
x = np.linspace(-8*np.pi, 8*np.pi, 2000)
# y vrednosti koristimo da pomerimo grafik duz y ose
# da bismo dobili pregledniji crtez
y = np.ones(2000)
# racunamo verzije funkcije definisanu u zadatku
f1 = f(np.sin, x, 1, 1, 0, 0)
ff1 = y*0
f2 = f(np.sin, x, 1, 2, 0, 2.5)
ff2 = y*2.5
f3 = f(np.sin, x, 2, 1, 0, -3)
ff3 = y*-3
f4 = f(np.sin, x, 0.5, 1, np.pi/2, 4.5)
ff4 = y*4.5
f5 = f(np.sin, x, 2, 4, 0, 7.5)
ff5 = y*7.5
f6 = f(np.sin,x , 3, 1/2, np.pi/3, -8)
ff6 = y*-8

# crtamo sve funkcije na istom grafiku
plt.figure(1)
plt.plot(x, f1, label=r"$(a,b,c,d) = (1,1,0,0)$")
plt.plot(x, f2, label=r"$(a,b,c,d) = (1,2,0,2)$")
plt.plot(x, f3, label=r"$(a,b,c,d) = (2,1,0,-3)$")
plt.plot(x, f4, label=r"$(a,b,c,d) = (0.5,1, \pi / 2,4)$")
plt.plot(x, f5, label=r"$(a,b,c,d) = (2,4,0,7)$")
plt.plot(x, f6, label=r"$(a,b,c,d) = (3,1/2,\pi / 3,-8)$")
plt.plot(x, ff1, 'k--', linewidth=0.8)
plt.plot(x, ff2, 'k--', linewidth=0.8)
plt.plot(x, ff3, 'k--', linewidth=0.8)
plt.plot(x, ff4, 'k--', linewidth=0.8)
plt.plot(x, ff5, 'k--', linewidth=0.8)
plt.plot(x, ff6, 'k--', linewidth=0.8)

plt.title(r"$f(x) = a \cdot sin(b \cdot x + c) + d$")

plt.xlabel(r"x")
plt.ylabel(r"f(x) = a \cdot sin(b \cdot x + c) + d")

plt.xlim([-8*np.pi, 8*np.pi])
plt.ylim([-11, 9.5])

plt.legend(bbox_to_anchor=(1, 1))
plt.grid()
plt.tight_layout()

# crtamo svaku funkciju pojedinacno na izdvojenom grafiku u okviru 
# istog crteza
fig, axs = plt.subplots(2, 3, figsize=(10, 6), layout='constrained')

axs[0][0].plot(x, f1, c='blue')
axs[0][0].set_xlabel(r"$x$")
axs[0][0].set_ylabel(r"$f(x)$")
axs[0][0].set_title(r"$f(x) = {} \cdot sin({} \cdot x)$".format(1,1))
axs[0][0].plot(x, ff1, 'k--')
axs[0][0].grid()

axs[0][1].plot(x, f2, c='orange')
axs[0][1].set_xlabel(r"$x$")
axs[0][1].set_ylabel(r"$f(x)$")
axs[0][1].set_title(r"$f(x) = {} \cdot sin({} \cdot x) + {}$".format(1,2,2))
axs[0][1].plot(x, ff2, 'k--')
axs[0][1].grid()

axs[0][2].plot(x, f3, c='green')
axs[0][2].set_xlabel(r"$x$")
axs[0][2].set_ylabel(r"$f(x)$")
axs[0][2].set_title(r"$f(x) = {} \cdot sin({} \cdot x)  {}$".format(2,1,-3))
axs[0][2].plot(x, ff3, 'k--')
axs[0][2].grid()

axs[1][0].plot(x, f4, c='red')
axs[1][0].set_xlabel(r"$x$")
axs[1][0].set_ylabel(r"$f(x)$")
axs[1][0].set_title(r"$f(x) = {} \cdot sin({} \cdot x + \pi / 2) + {}$".format(0.5,1,4))
axs[1][0].plot(x, ff4, 'k--')
axs[1][0].grid()

axs[1][1].plot(x, f5, c='magenta')
axs[1][1].set_xlabel(r"$x$")
axs[1][1].set_ylabel(r"$f(x)$")
axs[1][1].set_title(r"$f(x) = {} \cdot sin({} \cdot x) + {}$".format(2,4,7))
axs[1][1].plot(x, ff5, 'k--')
axs[1][1].grid()

axs[1][2].plot(x, f6, c='brown')
axs[1][2].set_xlabel(r"$x$")
axs[1][2].set_ylabel(r"$f(x)$")
axs[1][2].set_title(r"$f(x) = {} \cdot sin({} \cdot x + \pi / 3)  {}$".format(3,1/2,-8))
axs[1][2].plot(x, ff6, 'k--')
axs[1][2].grid()

fig.align_labels()

# na kraju prikazujemo crteze
plt.show()
