import scipy as scp
import matplotlib.pyplot as plt
import numpy as np

# Odrediti povrsinu i obim figure ogranicene
# krivama f(x) = sin(x) i g(x) = x^2.
# Nacrtati sliku koja prikazuje figuru.

# crtamo sliku da bismo okvirno uocili gde su 
# presecne tacke

x = np.linspace(0, 1, 1000)
fx = np.sin(x)
gx = x**2


plt.figure(1)
plt.plot(x, fx, label=r"$f(x) = sin(x)$")
plt.plot(x, gx, label=r"$g(x) = x^{2}$")

plt.xlabel("x")
plt.ylabel("y")
plt.title("Povrsina i obim figure")

plt.legend()
plt.grid()
plt.tight_layout()

# sa slike vidimo da su presecne tacke oko nule i izmedju 0.8 i 1
# da bismo odredili presecne tacke treba da resim jednacinu 
# oblika f(x) = g(x)
# zadatak cemo prevesti u f(x) - g(x) = 0 i resicemo ga numericki
# uz pomoc fsolve funkcije iz scipyoptimize paketa

# pravimo pomocnu funkciju koja predstavlja izraz f(x) - g(x)
f = lambda x: np.sin(x) - x**2
# odredjujemo presecne tacke. funkciji fsolve moramo da prosledimo
# pocetne procene nula.
nule = scp.optimize.fsolve(f, [0.1, 1])

# crtamo figuru
xx = np.linspace(nule[0], nule[1], 1000)
fx = np.sin(xx)
gx = xx**2

plt.figure(2)
plt.plot(xx, fx, label=r"$f(x) = sin(x)$")
plt.plot(xx, gx, label=r"$g(x) = x^{2}$")

# farbamo figuru ogranicenu krivama
plt.fill_between(xx, y1=gx, y2=fx, interpolate=True, color="#ccc")

plt.xlabel("x")
plt.ylabel("y")
plt.title("Povrsina i obim figure")

plt.legend()
plt.grid()
plt.tight_layout()


# odredjujemo povrsinu i obim

# povrsina je razlika povrsina
sinx = lambda x: np.sin(x)
x2 = lambda x: x ** 2
p1 = scp.integrate.quad(sinx, nule[0], nule[1])
p2 = scp.integrate.quad(x2, nule[0], nule[1])

print("Povrsina figure: {}".format(p1[0] - p2[0]))

# obim je zbir duzina lukova krivih f(x) i g(x) 
# na intervalu ogranicenom njihovim presecnim tackama

f1 = lambda x: np.sqrt(1 + (np.cos(x))**2)
g1 = lambda x: np.sqrt(1 + (2*x)**2)

o1 = scp.integrate.quad(f1, nule[0], nule[1])
o2 = scp.integrate.quad(g1, nule[0], nule[1])

print("Obim figure: {}".format(o1[0] + o2[0]))

# prikazujemo grafike
plt.show()
