import numpy as np
import sympy as smp
import matplotlib.pyplot as plt

# Ispitati tok i skicirati grafik funkcije
# f(x) = e^(x-2)/(x-1)

# definisemo simbol x
x = smp.symbols("x")
# definisemo simbolicku funkciju
fx = smp.exp(x - 2)/(x-1)

# tacka prekida je u x = 1
# pa racunamo levi i desni limes u toj tacki
llimes = smp.limit(fx, x, 1, '-')
dlimes = smp.limit(fx, x, 1, '+')

print("Levi limes: ", llimes)
print("Desni limes: ", dlimes)

# odredjujemo levu i desnu horizontalnu asimptotu
lha = smp.limit(fx, x, -np.inf)
dha = smp.limit(fx, x, np.inf)
print("Leva horizontalna asimptota: ", lha)
print("Desna horizontalna asimptota: ", dha)

# kose asimptote
lka_k = smp.limit(fx/x, x, -np.inf)
lka_n = smp.limit(fx/x - lka_k*x, x, -np.inf)
lka = lka_k*x + lka_n
print("Leva kosa asimptota: ", lka)

dka_k = smp.limit(fx/x, x, np.inf)
dka_n = smp.limit(fx/x - lka_k*x, x, np.inf)
dka = dka_k*x + dka_n
print("Desna kosa asimptota: ", dka)

# ekstremalne tacke
dfx = smp.diff(fx, x)
print("Izvod funkcije: ", dfx)

# odredjujemo nule prvog izvoda
nule_izvoda = smp.solve(smp.Eq(dfx, 0), x)
print("Nule prvog izvoda: ", nule_izvoda)
print("Minimum funkcija: ", nule_izvoda[0], fx.evalf(2, subs={x: nule_izvoda[0]}))

# prevojne tacke
dfx2 = smp.diff(fx, [x,2])
print("Drugi izvod funkcije: ", dfx2)

# odredjujemo prevojne tacke
prevojne_tacke = smp.solve(smp.Eq(dfx2, 0), x)
print("Nule drugog izvoda: ", prevojne_tacke)

# nema prevojnih tacaka

xx = np.linspace(-10, 10, 2000)
fxx = np.exp(xx-2)/(xx-1)
ha = np.zeros(len(xx))

plt.figure(1)
plt.plot(xx, fxx, label=r"$\frac{e^{x-2}}{(x-1)}$")
plt.plot([1,1], [-5,5], color='red', label=r"$Vertikalna asimptota: x = 1$", linewidth=2, linestyle='--')
plt.plot(xx, ha, color='orange', label=r"$Horizontalna asimptota: y = 0$", linewidth=2, linestyle='--')
plt.plot(smp.N(nule_izvoda[0]), fx.evalf(2, subs={x: nule_izvoda[0]}), color="red", marker='o', label="Minimum funkcije")

plt.title("Ispitivanje toka funkcije")
plt.ylim([-5,5])
plt.grid()
plt.legend()
plt.tight_layout()
plt.show()

